==> Cosmos.uv5.50.tar.gz: Tracking/csampGIntL.f <==
c        csampGIntL:  sample phtoto interaction length.
       subroutine csampGIntL
c
c        pair, compton, photo-electric eff. photo-hadron
c
       implicit none
#include  "Zglobalc.h"
#include  "Ztrack.h"
#include  "Ztrackp.h"
#include  "Ztrackv.h"
#include  "Zelemagp.h"

c

       real*8  t, tkgpm2, cxai, den, cvh2den, eg
       real*8  prob, u, cmPairMFP
       real*8 xaimin/0.1/
c     
       eg = TrackBefMove.p.fm.p(4)
       if(LpmEffect .and. eg .gt. LpmPairEmin) then
c          den = cthick2den(TrackBefMove.pos.depth)
          den = cvh2den(TrackBefMove.pos.height)  ! better
          call cpairLPMXsec(eg, den, prob)
          call rndc(u)
          t = -log(u) /prob
       else
          call cpairPath(eg, t)
       endif
       call csetIntInf(t*X0, .false., 'pair')
       if( eg .lt. MaxComptonE ) then
          call ccomptPath(eg, t) 
          call csetIntInf(t*X0, .false., 'compt')
       endif
       if( eg .lt. MaxPhotoE ) then
          call cphotoEEPath(eg, t)
          call csetIntInf(t*X0, .false., 'photoe')
       endif
       if( eg .gt. MinPhotoProdE .and. PhotoProd ) then
          call cghPath(eg,    tkgpm2)
          call csetIntInf(tkgpm2, .false., 'photop')
       endif
       if(MagPair .eq. 1 .and. eg .gt.  MagPairEmin) then
          Xai = cxai(TrackBefMove.p, Mag)
          if(Xai .gt. xaimin) then
             call rndc(u)
             t = -log(u) * cmPairMFP(eg, Xai)
             call csetIntInf(t, .true., 'mpair')
          else
             t = Infty
          endif
       endif
       end

==> Cosmos.uv6.16.tar.gz: Tracking/csampGIntL.f <==
c        csampGIntL:  sample phtoto interaction length.
       subroutine csampGIntL
c
c        pair, compton, photo-electric eff. photo-hadron
c
       implicit none
#include  "Zglobalc.h"
#include  "Ztrack.h"
#include  "Ztrackp.h"
#include  "Ztrackv.h"
#include  "Zelemagp.h"

c

       real*8  t, tkgpm2, cxai, den, cvh2den, eg
       real*8  prob, u, cmPairMFP
       real*8 xaimin/0.1/
c     
       eg = TrackBefMove.p.fm.p(4)
       if(LpmEffect .and. eg .gt. LpmPairEmin) then
c          den = cthick2den(TrackBefMove.pos.depth)
          den = cvh2den(TrackBefMove.pos.height)  ! better
          call cpairLPMXsec(eg, den, prob)
          call rndc(u)
          t = -log(u) /prob
       else
          call cpairPath(eg, t)
       endif
       call csetIntInf(t*X0, .false., 'pair')
       if( eg .lt. MaxComptonE ) then
          call ccomptPath(eg, prob, t) 
          call csetIntInf(t*X0, .false., 'compt')
       endif
       if( eg .lt. MaxPhotoE ) then
          call cphotoEEPath(eg, t)
          call csetIntInf(t*X0, .false., 'photoe')
       endif
       if( eg .gt. MinPhotoProdE .and. PhotoProd ) then
          call cghPath(eg,    tkgpm2)
          call csetIntInf(tkgpm2, .false., 'photop')
       endif
       if(MagPair .eq. 1 .and. eg .gt.  MagPairEmin) then
          Xai = cxai(TrackBefMove.p, Mag)
          if(Xai .gt. xaimin) then
             call rndc(u)
             t = -log(u) * cmPairMFP(eg, Xai)
             call csetIntInf(t, .true., 'mpair')
          else
             t = Infty
          endif
       endif
       end
